@@ -21,11 +21,13 @@ from . import version
 # runtime. If the patch would be placed at the beginning of the file, an empty
 # triple-quoted string is placed at the beginning so that the comment
 # "start delvewheel patch" does not show up when the built-in help system help()
-# is invoked on the package. For Python >=3.8, we use the os.add_dll_directory()
-# function so that the folder containing the vendored DLLs is added to the DLL
-# search path. For Python 3.7 or lower, this function is unavailable, so we
-# preload the DLLs. Whenever Python needs a vendored DLL, it will use the
-# already-loaded DLL instead of searching for it.
+# is invoked on the package. For non-Anaconda Python >= 3.8, we use the
+# os.add_dll_directory() function so that the folder containing the vendored
+# DLLs is added to the DLL search path. For Python 3.7 or lower, this function
+# is unavailable, so we preload the DLLs. Whenever Python needs a vendored DLL,
+# it will use the already-loaded DLL instead of searching for it. We also
+# preload the DLLs for Anaconda Python < 3.10, which has a bug where
+# os.add_dll_directory() does not always take effect.
 #
 # To use the template, call str.format(), passing in
 # 0. '""""""' if the patch would be at the start of the file else ''
@@ -39,19 +41,8 @@ def _delvewheel_init_patch_{1}():
     import os
     import sys
     libs_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir, {2!r}))
-    if sys.version_info[:2] >= (3, 8):
-        conda_workaround = os.path.exists(os.path.join(sys.base_prefix, 'conda-meta')) and (sys.version_info[:3] < (3, 8, 13) or (3, 9, 0) <= sys.version_info[:3] < (3, 9, 9))
-        if conda_workaround:
-            # backup the state of the environment variable CONDA_DLL_SEARCH_MODIFICATION_ENABLE
-            conda_dll_search_modification_enable = os.environ.get('CONDA_DLL_SEARCH_MODIFICATION_ENABLE')
-            os.environ['CONDA_DLL_SEARCH_MODIFICATION_ENABLE'] = '1'
+    if sys.version_info[:2] >= (3, 8) and not os.path.exists(os.path.join(sys.base_prefix, 'conda-meta')) or sys.version_info[:2] >= (3, 10):
         os.add_dll_directory(libs_dir)
-        if conda_workaround:
-            # restore the state of the environment variable CONDA_DLL_SEARCH_MODIFICATION_ENABLE
-            if conda_dll_search_modification_enable is None:
-                os.environ.pop('CONDA_DLL_SEARCH_MODIFICATION_ENABLE', None)
-            else:
-                os.environ['CONDA_DLL_SEARCH_MODIFICATION_ENABLE'] = conda_dll_search_modification_enable
     else:
         from ctypes import WinDLL
         with open(os.path.join(libs_dir, {3!r})) as file:
